@@ -87,4 +87,9 @@ def percentage(value):
 @register.filter(name='title_underscore')
 def field_name_to_label(value):
     value = value.replace('_', ' ')
-    return value.title()
\ No newline at end of file
+    return value.title()
+
+
+@register.filter(name='host_ip_address')
+def host_ip_address(value):
+    return value.split(':')[0]
